@@ -21,18 +21,21 @@
 #'
 #' @return The function displays the plot and returns invisible a list of the plot,
 #' the data.frame to make the plot, the vector of percentages of variance explained and the loadings matrix.
+#' @details If the `metadata` or `colData` of `obj` contain a column `colname`, this colum will be removed in the `$pca_data` slot,
+#' because this column contains the colnames of the data matrix. Similarly, for the `$loadings` slot, the column `rowname` is
+#' reserved for the rownames of the data matrix.
 #' @export
 plot_pca <- function(obj, PC_x = 1, PC_y = 2, n_feats = 500, scale_feats = FALSE, na_frac = .3, metadata = NULL, color_by = NULL, shape_by = NULL, point_alpha = .7, point_rel_size = 2, show_plot = TRUE) {
 
   # prevent 'no visible binding for global variable' package warnings
-  sample_id <- feature_id <- NULL
+  colname <- rowname <- NULL
 
   if (inherits(obj, "SummarizedExperiment")) {
     mat <- tryCatch(as.matrix(assay(obj)), error = function(e) {
       stop("Assay cannot be converted to a matrix.")
     })
     col_data <- as_tibble(colData(obj))
-    row_data <- as_tibble(rowData(obj), rownames = "feature_id")
+    row_data <- as_tibble(rowData(obj), rownames = "rowname")
   } else if (inherits(obj, "matrix")) {
     mat <- obj
     col_data <- NULL
@@ -41,7 +44,7 @@ plot_pca <- function(obj, PC_x = 1, PC_y = 2, n_feats = 500, scale_feats = FALSE
     stop("Object is not a matrix or SummarizedExperiment")
   }
 
-  mat[!is.finite(mat)] <- NA
+  mat[is.nan(mat)] <- NA
 
   # subset to features with maximum specified fraction of NAs
   nrow_mat_original <- nrow(mat)
@@ -60,33 +63,33 @@ plot_pca <- function(obj, PC_x = 1, PC_y = 2, n_feats = 500, scale_feats = FALSE
   # mean impute NAs
   mat_centered[is.na(mat_centered)] <- 0
   # subset to top-variable features
-  mat <- mat[matrixStats::rowVars(mat, na.rm = T) %>% order(decreasing = T) %>% head(n_feats), ]
+  mat_centered <- mat_centered[matrixStats::rowVars(mat_centered, na.rm = T) %>% order(decreasing = T) %>% head(n_feats), ]
   # do PCA
   pca <- prcomp(t(mat_centered))
-  pca_data <- as_tibble(pca$x, rownames = "sample_id")
+  pca_data <- as_tibble(pca$x, rownames = "colname")
   var_exp <- 100 * pca$sdev^2 / sum(pca$sdev^2)
 
   # join annotation
   if (!is.null(col_data)) {
-    pca_data <- bind_cols(pca_data, suppressWarnings(select(col_data, -tidyselect::any_of("sample_id"))))
+    pca_data <- bind_cols(pca_data, suppressWarnings(select(col_data, -tidyselect::any_of("colname"))))
   }
   if (!is.null(metadata)) {
-    pca_data <- bind_cols(pca_data, suppressWarnings(select(metadata, -tidyselect::any_of("sample_id"))))
+    pca_data <- bind_cols(pca_data, suppressWarnings(select(metadata, -tidyselect::any_of("colname"))))
   }
 
   # first annotation, then PCs
   pca_data <- pca_data %>%
-    select(sample_id, !tidyselect::starts_with("PC"), tidyselect::starts_with("PC"))
+    select(colname, !tidyselect::starts_with("PC"), tidyselect::starts_with("PC"))
 
-  loadings_data <- as_tibble(pca$rotation, rownames = "feature_id")
+  loadings_data <- as_tibble(pca$rotation, rownames = "rowname")
   # add row_data columns from SE object
   if (!is.null(row_data)) {
-    loadings_data <- left_join(loadings_data, row_data, by = "feature_id") %>%
-      select(feature_id, !tidyselect::starts_with("PC"), tidyselect::starts_with("PC"))
+    loadings_data <- left_join(loadings_data, row_data, by = "rowname") %>%
+      select(rowname, !tidyselect::starts_with("PC"), tidyselect::starts_with("PC"))
   }
 
   plot <- pca_data %>%
-    ggplot(aes_string(paste0("PC", PC_x), paste0("PC", PC_y), label = "sample_id", color = color_by, shape = shape_by)) +
+    ggplot(aes_string(paste0("PC", PC_x), paste0("PC", PC_y), label = "colname", color = color_by, shape = shape_by)) +
     geom_point(size = rel(point_rel_size), alpha = point_alpha) +
     coord_fixed() +
     labs(x = paste0("PC", PC_x, " (", round(var_exp[PC_x],1), "%)"), y = paste0("PC", PC_y, " (", round(var_exp[PC_y],1), "%)")) +
@@ -120,7 +123,7 @@ plot_pca <- function(obj, PC_x = 1, PC_y = 2, n_feats = 500, scale_feats = FALSE
 plot_loadings <- function(pca_res, PC = 1, color_by = NULL, annotate_top_n = 0, highlight_genes = NULL, show_plot = TRUE) {
 
   # prevent 'no visible binding for global variable' package warnings
-  feature_id <- ylim <- gene_name <- NULL
+  rowname <- ylim <- gene_name <- NULL
 
   loadings_df <- pca_res$loadings %>%
     select(!tidyselect::starts_with("PC"), PC = paste0("PC", PC)) %>%
@@ -132,7 +135,7 @@ plot_loadings <- function(pca_res, PC = 1, color_by = NULL, annotate_top_n = 0,
       (rank(PC) <= annotate_top_n) |
         (rank(-PC) <= annotate_top_n)
     ) %>%
-    pull(feature_id)
+    pull(rowname)
 
   if (is.null(highlight_genes)) {
     plot <- loadings_df %>%
@@ -140,7 +143,7 @@ plot_loadings <- function(pca_res, PC = 1, color_by = NULL, annotate_top_n = 0,
       geom_point() +
       # highlight top n
       ggrepel::geom_text_repel(data = loadings_df %>% filter(
-        feature_id %in% annotate_top_n_features
+        rowname %in% annotate_top_n_features
       )) +
       labs(x = paste0("rank(PC", PC, " loading)"), y = paste0("PC", PC, " loading")) +
       ylim(c(-max(abs(loadings_df$PC)), max(abs(loadings_df$PC)))) +
@@ -149,7 +152,7 @@ plot_loadings <- function(pca_res, PC = 1, color_by = NULL, annotate_top_n = 0,
     plot <- loadings_df %>%
       ggplot(aes_string(x = "PC_rank", y = "PC", label = "gene_name", color = color_by)) +
       geom_point() +
-      gghighlight::gghighlight(gene_name %in% highlight_genes | feature_id %in% highlight_genes,
+      gghighlight::gghighlight(gene_name %in% highlight_genes | rowname %in% highlight_genes,
         label_key = gene_name, use_group_by = F,
         label_params = list(fill = NA, label.size = NA, fontface = "bold")
       ) +
@@ -180,11 +183,12 @@ plot_loadings <- function(pca_res, PC = 1, color_by = NULL, annotate_top_n = 0,
 #' @param point_rel_size relative size of `geom_point()`
 #'
 #' @examples
+#' \donttest{
 #' set.seed(1)
 #' data <- matrix(rnorm(100*6), ncol=6)
 #' data <- t(t(data)+c(-1, -1.1, -1.2, 1, 1.1, 1.2))
 #' plot_pca_scatters(data)
-#'
+#' }
 #' @return The function displays the scatter plots of the PCs
 #' @export
 plot_pca_scatters <- function(obj, n_PCs = min(10,nrow(obj),ncol(obj)), show_var_exp = T, n_feats = 500, scale_feats = FALSE, na_frac = 0.3, metadata = NULL, color_by = NULL, shape_by = NULL, point_alpha = 0.7, point_rel_size = 2){
